@@ -8,22 +8,28 @@
 
 #include <QStyle>
 
-namespace {
-    // Disable the 'Floatable' feature, i.e., the possibility to drag the
-    // dock widget out of the main window. This works around problems like
-    // https://bugs.kde.org/show_bug.cgi?id=288629
-    // https://bugs.kde.org/show_bug.cgi?id=322299
-    const QDockWidget::DockWidgetFeatures DefaultDockWidgetFeatures = QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetClosable;
+namespace
+{
+// Disable the 'Floatable' feature, i.e., the possibility to drag the
+// dock widget out of the main window. This works around problems like
+// https://bugs.kde.org/show_bug.cgi?id=288629
+// https://bugs.kde.org/show_bug.cgi?id=322299
+const QDockWidget::DockWidgetFeatures DefaultDockWidgetFeatures = QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetClosable;
 }
 
- // Empty titlebar for the dock widgets when "Lock Layout" has been activated.
+// Empty titlebar for the dock widgets when "Lock Layout" has been activated.
 class DolphinDockTitleBar : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit DolphinDockTitleBar(QWidget* parent = nullptr) : QWidget(parent) {}
-    ~DolphinDockTitleBar() override {}
+    explicit DolphinDockTitleBar(QWidget *parent = nullptr)
+        : QWidget(parent)
+    {
+    }
+    ~DolphinDockTitleBar() override
+    {
+    }
 
     QSize minimumSizeHint() const override
     {
@@ -37,10 +43,10 @@ public:
     }
 };
 
-DolphinDockWidget::DolphinDockWidget(const QString& title, QWidget* parent, Qt::WindowFlags flags) :
-    QDockWidget(title, parent, flags),
-    m_locked(false),
-    m_dockTitleBar(nullptr)
+DolphinDockWidget::DolphinDockWidget(const QString &title, QWidget *parent, Qt::WindowFlags flags)
+    : QDockWidget(title, parent, flags)
+    , m_locked(false)
+    , m_dockTitleBar(nullptr)
 {
     setFeatures(DefaultDockWidgetFeatures);
 }
