@@ -48,11 +48,10 @@
 
 K_PLUGIN_CLASS_WITH_JSON(DolphinPart, "dolphinpart.json")
 
-DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent,
-                         const KPluginMetaData& metaData, const QVariantList& args)
+DolphinPart::DolphinPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : KParts::ReadOnlyPart(parent)
-      ,m_openTerminalAction(nullptr)
-      ,m_removeAction(nullptr)
+    , m_openTerminalAction(nullptr)
+    , m_removeAction(nullptr)
 {
     Q_UNUSED(args)
     setMetaData(metaData);
@@ -66,8 +65,7 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent,
     m_view->setTabsForFilesEnabled(true);
     setWidget(m_view);
 
-    connect(&DolphinNewFileMenuObserver::instance(), &DolphinNewFileMenuObserver::errorMessage,
-            this, &DolphinPart::slotErrorMessage);
+    connect(&DolphinNewFileMenuObserver::instance(), &DolphinNewFileMenuObserver::errorMessage, this, &DolphinPart::slotErrorMessage);
 
     connect(m_view, &DolphinView::directoryLoadingCompleted, this, &KParts::ReadOnlyPart::completed);
     connect(m_view, &DolphinView::directoryLoadingCompleted, this, &DolphinPart::updatePasteAction);
@@ -76,51 +74,37 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent,
 
     setXMLFile(QStringLiteral("dolphinpart.rc"));
 
-    connect(m_view, &DolphinView::infoMessage,
-            this, &DolphinPart::slotMessage);
-    connect(m_view, &DolphinView::operationCompletedMessage,
-            this, &DolphinPart::slotMessage);
-    connect(m_view, &DolphinView::errorMessage,
-            this, &DolphinPart::slotErrorMessage);
-    connect(m_view, &DolphinView::itemActivated,
-            this, &DolphinPart::slotItemActivated);
-    connect(m_view, &DolphinView::itemsActivated,
-            this, &DolphinPart::slotItemsActivated);
+    connect(m_view, &DolphinView::infoMessage, this, &DolphinPart::slotMessage);
+    connect(m_view, &DolphinView::operationCompletedMessage, this, &DolphinPart::slotMessage);
+    connect(m_view, &DolphinView::errorMessage, this, &DolphinPart::slotErrorMessage);
+    connect(m_view, &DolphinView::itemActivated, this, &DolphinPart::slotItemActivated);
+    connect(m_view, &DolphinView::itemsActivated, this, &DolphinPart::slotItemsActivated);
     connect(m_view, &DolphinView::statusBarTextChanged, this, [this](const QString &text) {
         const QString escapedText = Qt::convertFromPlainText(text);
         Q_EMIT ReadOnlyPart::setStatusBarText(QStringLiteral("<qt>%1</qt>").arg(escapedText));
     });
-    connect(m_view, &DolphinView::tabRequested,
-            this, &DolphinPart::createNewWindow);
-    connect(m_view, &DolphinView::requestContextMenu,
-            this, &DolphinPart::slotOpenContextMenu);
-    connect(m_view, &DolphinView::selectionChanged,
-            m_extension, &KParts::BrowserExtension::selectionInfo);
-    connect(m_view, &DolphinView::selectionChanged,
-            this, &DolphinPart::slotSelectionChanged);
-    connect(m_view, &DolphinView::requestItemInfo,
-            this, &DolphinPart::slotRequestItemInfo);
-    connect(m_view, &DolphinView::modeChanged,
-            this, &DolphinPart::viewModeChanged); // relay signal
-    connect(m_view, &DolphinView::redirection,
-            this, &DolphinPart::slotDirectoryRedirection);
+    connect(m_view, &DolphinView::tabRequested, this, &DolphinPart::createNewWindow);
+    connect(m_view, &DolphinView::requestContextMenu, this, &DolphinPart::slotOpenContextMenu);
+    connect(m_view, &DolphinView::selectionChanged, m_extension, &KParts::BrowserExtension::selectionInfo);
+    connect(m_view, &DolphinView::selectionChanged, this, &DolphinPart::slotSelectionChanged);
+    connect(m_view, &DolphinView::requestItemInfo, this, &DolphinPart::slotRequestItemInfo);
+    connect(m_view, &DolphinView::modeChanged, this, &DolphinPart::viewModeChanged); // relay signal
+    connect(m_view, &DolphinView::redirection, this, &DolphinPart::slotDirectoryRedirection);
 
     // Watch for changes that should result in updates to the
     // status bar text.
     connect(m_view, &DolphinView::itemCountChanged, this, &DolphinPart::updateStatusBar);
-    connect(m_view,  &DolphinView::selectionChanged, this, &DolphinPart::updateStatusBar);
+    connect(m_view, &DolphinView::selectionChanged, this, &DolphinPart::updateStatusBar);
 
     m_actionHandler = new DolphinViewActionHandler(actionCollection(), nullptr, this);
     m_actionHandler->setCurrentView(m_view);
     connect(m_actionHandler, &DolphinViewActionHandler::createDirectoryTriggered, this, &DolphinPart::createDirectory);
 
     m_remoteEncoding = new DolphinRemoteEncoding(this, m_actionHandler);
-    connect(this, &DolphinPart::aboutToOpenURL,
-            m_remoteEncoding, &DolphinRemoteEncoding::slotAboutToOpenUrl);
+    connect(this, &DolphinPart::aboutToOpenURL, m_remoteEncoding, &DolphinRemoteEncoding::slotAboutToOpenUrl);
 
-    QClipboard* clipboard = QApplication::clipboard();
-    connect(clipboard, &QClipboard::dataChanged,
-            this, &DolphinPart::updatePasteAction);
+    QClipboard *clipboard = QApplication::clipboard();
+    connect(clipboard, &QClipboard::dataChanged, this, &DolphinPart::updatePasteAction);
 
     // Create file info and listing filter extensions.
     // NOTE: Listing filter needs to be instantiated after the creation of the view.
@@ -128,9 +112,9 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent,
 
     new DolphinPartListingFilterExtension(this);
 
-    KDirLister* lister = m_view->m_model->m_dirLister;
+    KDirLister *lister = m_view->m_model->m_dirLister;
     if (lister) {
-        DolphinPartListingNotificationExtension* notifyExt = new DolphinPartListingNotificationExtension(this);
+        DolphinPartListingNotificationExtension *notifyExt = new DolphinPartListingNotificationExtension(this);
         connect(lister, &KDirLister::newItems, notifyExt, &DolphinPartListingNotificationExtension::slotNewItems);
         connect(lister, &KDirLister::itemsDeleted, notifyExt, &DolphinPartListingNotificationExtension::slotItemsDeleted);
     } else {
@@ -159,29 +143,28 @@ void DolphinPart::createActions()
 
     m_newFileMenu = new DolphinNewFileMenu(actionCollection(), this);
     m_newFileMenu->setParentWidget(widget());
-    connect(m_newFileMenu->menu(), &QMenu::aboutToShow,
-            this, &DolphinPart::updateNewMenu);
+    connect(m_newFileMenu->menu(), &QMenu::aboutToShow, this, &DolphinPart::updateNewMenu);
 
-    QAction *editMimeTypeAction = actionCollection()->addAction( QStringLiteral("editMimeType") );
-    editMimeTypeAction->setText( i18nc("@action:inmenu Edit", "&Edit File Type..." ) );
+    QAction *editMimeTypeAction = actionCollection()->addAction(QStringLiteral("editMimeType"));
+    editMimeTypeAction->setText(i18nc("@action:inmenu Edit", "&Edit File Type..."));
     connect(editMimeTypeAction, &QAction::triggered, this, &DolphinPart::slotEditMimeType);
 
-    QAction* selectItemsMatching = actionCollection()->addAction(QStringLiteral("select_items_matching"));
+    QAction *selectItemsMatching = actionCollection()->addAction(QStringLiteral("select_items_matching"));
     selectItemsMatching->setText(i18nc("@action:inmenu Edit", "Select Items Matching..."));
     actionCollection()->setDefaultShortcut(selectItemsMatching, Qt::CTRL | Qt::Key_S);
     connect(selectItemsMatching, &QAction::triggered, this, &DolphinPart::slotSelectItemsMatchingPattern);
 
-    QAction* unselectItemsMatching = actionCollection()->addAction(QStringLiteral("unselect_items_matching"));
+    QAction *unselectItemsMatching = actionCollection()->addAction(QStringLiteral("unselect_items_matching"));
     unselectItemsMatching->setText(i18nc("@action:inmenu Edit", "Unselect Items Matching..."));
     connect(unselectItemsMatching, &QAction::triggered, this, &DolphinPart::slotUnselectItemsMatchingPattern);
 
     KStandardAction::selectAll(m_view, &DolphinView::selectAll, actionCollection());
 
-    QAction* unselectAll = actionCollection()->addAction(QStringLiteral("unselect_all"));
+    QAction *unselectAll = actionCollection()->addAction(QStringLiteral("unselect_all"));
     unselectAll->setText(i18nc("@action:inmenu Edit", "Unselect All"));
     connect(unselectAll, &QAction::triggered, m_view, &DolphinView::clearSelection);
 
-    QAction* invertSelection = actionCollection()->addAction(QStringLiteral("invert_selection"));
+    QAction *invertSelection = actionCollection()->addAction(QStringLiteral("invert_selection"));
     invertSelection->setText(i18nc("@action:inmenu Edit", "Invert Selection"));
     actionCollection()->setDefaultShortcut(invertSelection, Qt::CTRL | Qt::SHIFT | Qt::Key_A);
     connect(invertSelection, &QAction::triggered, m_view, &DolphinView::invertSelection);
@@ -190,21 +173,16 @@ void DolphinPart::createActions()
 
     // Go menu
 
-    QActionGroup* goActionGroup = new QActionGroup(this);
-    connect(goActionGroup, &QActionGroup::triggered,
-            this, &DolphinPart::slotGoTriggered);
+    QActionGroup *goActionGroup = new QActionGroup(this);
+    connect(goActionGroup, &QActionGroup::triggered, this, &DolphinPart::slotGoTriggered);
 
-    createGoAction("go_applications", "start-here-kde",
-                   i18nc("@action:inmenu Go", "App&lications"), QStringLiteral("programs:/"),
-                   goActionGroup);
-    createGoAction("go_network_folders", "folder-remote",
-                   i18nc("@action:inmenu Go", "&Network Folders"), QStringLiteral("remote:/"),
-                   goActionGroup);
-    createGoAction("go_trash", "user-trash",
-                   i18nc("@action:inmenu Go", "Trash"), QStringLiteral("trash:/"),
-                   goActionGroup);
-    createGoAction("go_autostart", "",
-                   i18nc("@action:inmenu Go", "Autostart"), QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/autostart",
+    createGoAction("go_applications", "start-here-kde", i18nc("@action:inmenu Go", "App&lications"), QStringLiteral("programs:/"), goActionGroup);
+    createGoAction("go_network_folders", "folder-remote", i18nc("@action:inmenu Go", "&Network Folders"), QStringLiteral("remote:/"), goActionGroup);
+    createGoAction("go_trash", "user-trash", i18nc("@action:inmenu Go", "Trash"), QStringLiteral("trash:/"), goActionGroup);
+    createGoAction("go_autostart",
+                   "",
+                   i18nc("@action:inmenu Go", "Autostart"),
+                   QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/autostart",
                    goActionGroup);
 
     // Tools menu
@@ -222,33 +200,31 @@ void DolphinPart::createActions()
 #endif
 }
 
-void DolphinPart::createGoAction(const char* name, const char* iconName,
-                                 const QString& text, const QString& url,
-                                 QActionGroup* actionGroup)
+void DolphinPart::createGoAction(const char *name, const char *iconName, const QString &text, const QString &url, QActionGroup *actionGroup)
 {
-    QAction* action = actionCollection()->addAction(name);
+    QAction *action = actionCollection()->addAction(name);
     action->setIcon(QIcon::fromTheme(iconName));
     action->setText(text);
     action->setData(url);
     action->setActionGroup(actionGroup);
 }
 
-void DolphinPart::slotGoTriggered(QAction* action)
+void DolphinPart::slotGoTriggered(QAction *action)
 {
     const QString url = action->data().toString();
     Q_EMIT m_extension->openUrlRequest(QUrl(url));
 }
 
-void DolphinPart::slotSelectionChanged(const KFileItemList& selection)
+void DolphinPart::slotSelectionChanged(const KFileItemList &selection)
 {
     const bool hasSelection = !selection.isEmpty();
 
-    QAction* renameAction  = actionCollection()->action(KStandardAction::name(KStandardAction::RenameFile));
-    QAction* moveToTrashAction = actionCollection()->action(KStandardAction::name(KStandardAction::MoveToTrash));
-    QAction* deleteAction = actionCollection()->action(KStandardAction::name(KStandardAction::DeleteFile));
-    QAction* editMimeTypeAction = actionCollection()->action(QStringLiteral("editMimeType"));
-    QAction* propertiesAction = actionCollection()->action(QStringLiteral("properties"));
-    QAction* deleteWithTrashShortcut = actionCollection()->action(QStringLiteral("delete_shortcut")); // see DolphinViewActionHandler
+    QAction *renameAction = actionCollection()->action(KStandardAction::name(KStandardAction::RenameFile));
+    QAction *moveToTrashAction = actionCollection()->action(KStandardAction::name(KStandardAction::MoveToTrash));
+    QAction *deleteAction = actionCollection()->action(KStandardAction::name(KStandardAction::DeleteFile));
+    QAction *editMimeTypeAction = actionCollection()->action(QStringLiteral("editMimeType"));
+    QAction *propertiesAction = actionCollection()->action(QStringLiteral("properties"));
+    QAction *deleteWithTrashShortcut = actionCollection()->action(QStringLiteral("delete_shortcut")); // see DolphinViewActionHandler
 
     if (!hasSelection) {
         stateChanged(QStringLiteral("has_no_selection"));
@@ -279,13 +255,13 @@ void DolphinPart::slotSelectionChanged(const KFileItemList& selection)
 void DolphinPart::updatePasteAction()
 {
     QPair<bool, QString> pasteInfo = m_view->pasteInfo();
-    Q_EMIT m_extension->enableAction( "paste", pasteInfo.first );
-    Q_EMIT m_extension->setActionText( "paste", pasteInfo.second );
+    Q_EMIT m_extension->enableAction("paste", pasteInfo.first);
+    Q_EMIT m_extension->setActionText("paste", pasteInfo.second);
 }
 
 QString DolphinPart::urlToLocalFilePath(const QUrl &url)
 {
-    KIO::StatJob* statJob = KIO::mostLocalUrl(url);
+    KIO::StatJob *statJob = KIO::mostLocalUrl(url);
     KJobWidgets::setWindow(statJob, widget());
     statJob->exec();
     QUrl localUrl = statJob->mostLocalUrl();
@@ -331,19 +307,19 @@ bool DolphinPart::openUrl(const QUrl &url)
     return true;
 }
 
-void DolphinPart::slotMessage(const QString& msg)
+void DolphinPart::slotMessage(const QString &msg)
 {
     Q_EMIT setStatusBarText(msg);
 }
 
-void DolphinPart::slotErrorMessage(const QString& msg)
+void DolphinPart::slotErrorMessage(const QString &msg)
 {
     qCDebug(DolphinDebug) << msg;
     Q_EMIT canceled(msg);
     //KMessageBox::error(m_view, msg);
 }
 
-void DolphinPart::slotRequestItemInfo(const KFileItem& item)
+void DolphinPart::slotRequestItemInfo(const KFileItem &item)
 {
     Q_EMIT m_extension->mouseOverInfo(item);
     if (item.isNull()) {
@@ -354,7 +330,7 @@ void DolphinPart::slotRequestItemInfo(const KFileItem& item)
     }
 }
 
-void DolphinPart::slotItemActivated(const KFileItem& item)
+void DolphinPart::slotItemActivated(const KFileItem &item)
 {
     KParts::OpenUrlArguments args;
     // Forget about the known mimetype if a target URL is used.
@@ -370,28 +346,24 @@ void DolphinPart::slotItemActivated(const KFileItem& item)
     Q_EMIT m_extension->openUrlRequest(item.targetUrl(), args, browserArgs);
 }
 
-void DolphinPart::slotItemsActivated(const KFileItemList& items)
+void DolphinPart::slotItemsActivated(const KFileItemList &items)
 {
-    for (const KFileItem& item : items) {
+    for (const KFileItem &item : items) {
         slotItemActivated(item);
     }
 }
 
-void DolphinPart::createNewWindow(const QUrl& url)
+void DolphinPart::createNewWindow(const QUrl &url)
 {
     // TODO: Check issue N176832 for the missing QAIV signal; task 177399 - maybe this code
     // should be moved into DolphinPart::slotItemActivated()
     Q_EMIT m_extension->createNewWindow(url);
 }
 
-void DolphinPart::slotOpenContextMenu(const QPoint& pos,
-                                      const KFileItem& _item,
-                                      const KFileItemList &selectedItems,
-                                      const QUrl &)
+void DolphinPart::slotOpenContextMenu(const QPoint &pos, const KFileItem &_item, const KFileItemList &selectedItems, const QUrl &)
 {
-    KParts::BrowserExtension::PopupFlags popupFlags = KParts::BrowserExtension::DefaultPopupItems
-                                                      | KParts::BrowserExtension::ShowProperties
-                                                      | KParts::BrowserExtension::ShowUrlOperations;
+    KParts::BrowserExtension::PopupFlags popupFlags =
+        KParts::BrowserExtension::DefaultPopupItems | KParts::BrowserExtension::ShowProperties | KParts::BrowserExtension::ShowUrlOperations;
 
     KFileItem item(_item);
 
@@ -420,8 +392,7 @@ void DolphinPart::slotOpenContextMenu(const QPoint& pos,
         const bool supportsMoving = capabilities.supportsMoving();
 
         if (capabilities.supportsDeleting()) {
-            const bool showDeleteAction = (KSharedConfig::openConfig()->group("KDE").readEntry("ShowDeleteCommand", false) ||
-                                           !item.isLocalFile());
+            const bool showDeleteAction = (KSharedConfig::openConfig()->group("KDE").readEntry("ShowDeleteCommand", false) || !item.isLocalFile());
             const bool showMoveToTrashAction = capabilities.isLocal() && supportsMoving;
 
             if (showDeleteAction && showMoveToTrashAction) {
@@ -450,17 +421,11 @@ void DolphinPart::slotOpenContextMenu(const QPoint& pos,
         // But in treeview mode we should allow it.
         if (m_view->itemsExpandable())
             popupFlags |= KParts::BrowserExtension::ShowCreateDirectory;
-
     }
 
     actionGroups.insert(QStringLiteral("editactions"), editActions);
 
-    Q_EMIT m_extension->popupMenu(pos,
-                                items,
-                                KParts::OpenUrlArguments(),
-                                KParts::BrowserArguments(),
-                                popupFlags,
-                                actionGroups);
+    Q_EMIT m_extension->popupMenu(pos, items, KParts::OpenUrlArguments(), KParts::BrowserArguments(), popupFlags, actionGroups);
 }
 
 void DolphinPart::slotDirectoryRedirection(const QUrl &oldUrl, const QUrl &newUrl)
@@ -473,7 +438,6 @@ void DolphinPart::slotDirectoryRedirection(const QUrl &oldUrl, const QUrl &newUr
     }
 }
 
-
 void DolphinPart::slotEditMimeType()
 {
     const KFileItemList items = m_view->selectedItems();
@@ -484,19 +448,15 @@ void DolphinPart::slotEditMimeType()
 
 void DolphinPart::slotSelectItemsMatchingPattern()
 {
-    openSelectionDialog(i18nc("@title:window", "Select"),
-                        i18n("Select all items matching this pattern:"),
-                        true);
+    openSelectionDialog(i18nc("@title:window", "Select"), i18n("Select all items matching this pattern:"), true);
 }
 
 void DolphinPart::slotUnselectItemsMatchingPattern()
 {
-    openSelectionDialog(i18nc("@title:window", "Unselect"),
-                        i18n("Unselect all items matching this pattern:"),
-                        false);
+    openSelectionDialog(i18nc("@title:window", "Unselect"), i18n("Unselect all items matching this pattern:"), false);
 }
 
-void DolphinPart::openSelectionDialog(const QString& title, const QString& text, bool selectItems)
+void DolphinPart::openSelectionDialog(const QString &title, const QString &text, bool selectItems)
 {
     auto *dialog = new QInputDialog(m_view);
     dialog->setAttribute(Qt::WA_DeleteOnClose, true);
@@ -532,9 +492,9 @@ void DolphinPart::openSelectionDialog(const QString& title, const QString& text,
     dialog->open();
 }
 
-void DolphinPart::setCurrentViewMode(const QString& viewModeName)
+void DolphinPart::setCurrentViewMode(const QString &viewModeName)
 {
-    QAction* action = actionCollection()->action(viewModeName);
+    QAction *action = actionCollection()->action(viewModeName);
     Q_ASSERT(action);
     action->trigger();
 }
@@ -544,7 +504,7 @@ QString DolphinPart::currentViewMode() const
     return m_actionHandler->currentViewModeActionName();
 }
 
-void DolphinPart::setNameFilter(const QString& nameFilter)
+void DolphinPart::setNameFilter(const QString &nameFilter)
 {
     // This is the "/home/dfaure/*.diff" kind of name filter (KDirLister::setNameFilter)
     // which is unrelated to DolphinView::setNameFilter which is substring filtering in a proxy.
@@ -571,10 +531,8 @@ void DolphinPart::slotOpenTerminal()
 void DolphinPart::slotFindFile()
 {
     QMenu searchTools;
-    KMoreToolsMenuFactory("dolphin/search-tools").fillMenuFromGroupingNames(
-        &searchTools, { "files-find" }, QUrl::fromLocalFile(localFilePathOrHome())
-    );
-    QList<QAction*> actions = searchTools.actions();
+    KMoreToolsMenuFactory("dolphin/search-tools").fillMenuFromGroupingNames(&searchTools, {"files-find"}, QUrl::fromLocalFile(localFilePathOrHome()));
+    QList<QAction *> actions = searchTools.actions();
     if (!(actions.isEmpty())) {
         actions.first()->trigger();
     } else {
@@ -617,7 +575,7 @@ void DolphinPart::createDirectory()
     m_newFileMenu->createDirectory();
 }
 
-void DolphinPart::setFilesToSelect(const QList<QUrl>& files)
+void DolphinPart::setFilesToSelect(const QList<QUrl> &files)
 {
     if (files.isEmpty()) {
         return;
@@ -627,15 +585,15 @@ void DolphinPart::setFilesToSelect(const QList<QUrl>& files)
     m_view->markUrlAsCurrent(files.at(0));
 }
 
-bool DolphinPart::eventFilter(QObject* obj, QEvent* event)
+bool DolphinPart::eventFilter(QObject *obj, QEvent *event)
 {
     using ShiftState = DolphinRemoveAction::ShiftState;
     const int type = event->type();
 
     if ((type == QEvent::KeyPress || type == QEvent::KeyRelease) && m_removeAction) {
-        QMenu* menu = qobject_cast<QMenu*>(obj);
+        QMenu *menu = qobject_cast<QMenu *>(obj);
         if (menu && menu->parent() == m_view) {
-            QKeyEvent* ev = static_cast<QKeyEvent*>(event);
+            QKeyEvent *ev = static_cast<QKeyEvent *>(event);
             if (ev->key() == Qt::Key_Shift) {
                 m_removeAction->update(type == QEvent::KeyPress ? ShiftState::Pressed : ShiftState::Released);
             }
