@@ -21,8 +21,8 @@ namespace SelectionMode
 class SingleClickSelectionProxyStyle : public QProxyStyle
 {
 public:
-    inline int styleHint(StyleHint hint, const QStyleOption *option = nullptr,
-                  const QWidget *widget = nullptr, QStyleHintReturn *returnData = nullptr) const override
+    inline int
+    styleHint(StyleHint hint, const QStyleOption *option = nullptr, const QWidget *widget = nullptr, QStyleHintReturn *returnData = nullptr) const override
     {
         if (hint == QStyle::SH_ItemView_ActivateItemOnSingleClick) {
             return 0;
